# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.lookup_api import LookupApi


class TestLookupApi(unittest.TestCase):
    """LookupApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LookupApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_lookup_environments_get(self) -> None:
        """Test case for api_v1_lookup_environments_get

        Get Environments
        """
        pass

    def test_api_v1_lookup_languages_get(self) -> None:
        """Test case for api_v1_lookup_languages_get

        Lookup Supported Languages
        """
        pass

    def test_api_v1_lookup_snippets_sync_post(self) -> None:
        """Test case for api_v1_lookup_snippets_sync_post

        Sync client snippets
        """
        pass

    def test_api_v1_lookup_states_code_get(self) -> None:
        """Test case for api_v1_lookup_states_code_get

        Get US State by Code
        """
        pass

    def test_api_v1_lookup_states_get(self) -> None:
        """Test case for api_v1_lookup_states_get

        Get US States
        """
        pass

    def test_api_v1_lookup_uids_get(self) -> None:
        """Test case for api_v1_lookup_uids_get

        Get legacy uids for matching knowledge data
        """
        pass

    def test_api_v1_lookup_user_roles_get(self) -> None:
        """Test case for api_v1_lookup_user_roles_get

        Get Possible User Roles
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_report_artifact_list_response import ReportsReportArtifactListResponse

class TestReportsReportArtifactListResponse(unittest.TestCase):
    """ReportsReportArtifactListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsReportArtifactListResponse:
        """Test ReportsReportArtifactListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsReportArtifactListResponse`
        """
        model = ReportsReportArtifactListResponse()
        if include_optional:
            return ReportsReportArtifactListResponse(
                data = [
                    neurograph.v1.models.reports/report_artifact_response.reports.ReportArtifactResponse(
                        ai_call_to_action = '', 
                        ai_generated_at = '', 
                        ai_key_highlights = [
                            ''
                            ], 
                        ai_main_insights = [
                            ''
                            ], 
                        client_id = 'cli_abc', 
                        created_by = '', 
                        description = '', 
                        embed_url = 'https://gamma.app/embed/...', 
                        error = '', 
                        executive_summary = '', 
                        id = '', 
                        key_stats = [
                            56
                            ], 
                        linked_concepts = [
                            ''
                            ], 
                        linked_kpis = [
                            neurograph.v1.models.reports/linked_kpi.reports.LinkedKPI(
                                change = '+0.4%', 
                                kpi_id = 'kpi_12345', 
                                kpi_name = 'Conversion Rate', 
                                trend = 'up', 
                                value = '3.2%', )
                            ], 
                        linked_queries = [
                            neurograph.v1.models.reports/linked_query.reports.LinkedQuery(
                                description = 'Products with highest conversion in Q4', 
                                query_id = 'qry_67890', 
                                query_name = 'Top Converting Products', )
                            ], 
                        linked_themes = [
                            ''
                            ], 
                        linked_topics = [
                            ''
                            ], 
                        markdown_content = '', 
                        markdown_updated_at = '', 
                        markdown_updated_by = '', 
                        metadata = [
                            56
                            ], 
                        name = 'Q4 2024 Persona Analysis', 
                        og_image_generated_at = '', 
                        og_image_url = '', 
                        og_image_version = 56, 
                        organization_id = '', 
                        pdf_url = '', 
                        presentation_url = 'https://gamma.app/docs/...', 
                        recommendations = [
                            neurograph.v1.models.reports/recommendation.reports.Recommendation(
                                action_url = '/campaigns/create?segment=a', 
                                category = 'engagement', 
                                id = '', 
                                priority = 'high', 
                                title = 'Increase email frequency for Segment A', )
                            ], 
                        report_type = 'monthly_persona_readout', 
                        thumbnail_url = '', 
                        ts_created = '', 
                        ts_updated = '', 
                        updated_by = '', )
                    ],
                error = '',
                limit = 56,
                page = 56,
                total = 56,
                total_pages = 56
            )
        else:
            return ReportsReportArtifactListResponse(
        )
        """

    def testReportsReportArtifactListResponse(self):
        """Test ReportsReportArtifactListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_model_insights_response import ReportingModelInsightsResponse

class TestReportingModelInsightsResponse(unittest.TestCase):
    """ReportingModelInsightsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingModelInsightsResponse:
        """Test ReportingModelInsightsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingModelInsightsResponse`
        """
        model = ReportingModelInsightsResponse()
        if include_optional:
            return ReportingModelInsightsResponse(
                cached = True,
                daily_predictions = [
                    neurograph.v1.models.reporting/daily_predictions.reporting.DailyPredictions(
                        date = '', 
                        total = 56, )
                    ],
                date_range = neurograph.v1.models.reporting/date_range.reporting.DateRange(
                    end_date = '', 
                    start_date = '', ),
                error = '',
                jobs_over_time = [
                    neurograph.v1.models.reporting/model_jobs_over_time.reporting.ModelJobsOverTime(
                        date = '', 
                        job_count = 56, 
                        model_type = '', )
                    ],
                query_time_ms = 56,
                recent_jobs = [
                    neurograph.v1.models.reporting/model_job_summary.reporting.ModelJobSummary(
                        active_build = 56, 
                        assignment_date = '', 
                        build_timestamp = '', 
                        client_id = '', 
                        client_name = '', 
                        job_id = '', 
                        model_type = '', 
                        model_version = '', 
                        org_name = '', 
                        prediction_count = 56, )
                    ],
                stats = neurograph.v1.models.reporting/model_job_stats.reporting.ModelJobStats(
                    active_builds = 56, 
                    latest_version = '', 
                    total_jobs = 56, 
                    total_predictions = 56, 
                    unique_versions = 56, ),
                version_stats = [
                    neurograph.v1.models.reporting/model_version_stats.reporting.ModelVersionStats(
                        job_count = 56, 
                        latest_build = '', 
                        model_version = '', )
                    ]
            )
        else:
            return ReportingModelInsightsResponse(
        )
        """

    def testReportingModelInsightsResponse(self):
        """Test ReportingModelInsightsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.pixel_client_pixel_details_response import PixelClientPixelDetailsResponse

class TestPixelClientPixelDetailsResponse(unittest.TestCase):
    """PixelClientPixelDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PixelClientPixelDetailsResponse:
        """Test PixelClientPixelDetailsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PixelClientPixelDetailsResponse`
        """
        model = PixelClientPixelDetailsResponse()
        if include_optional:
            return PixelClientPixelDetailsResponse(
                cached = True,
                client_info = neurograph.v1.models.pixel/client_info.pixel.ClientInfo(
                    client_uid = '', 
                    domain = '', 
                    org_uid = '', ),
                daily_metrics = [
                    neurograph.v1.models.pixel/daily_client_pixel_metrics.pixel.DailyClientPixelMetrics(
                        avg_match_confidence = 1.337, 
                        avg_session_duration = 1.337, 
                        daily_cost = 1.337, 
                        date = '', 
                        enriched_visitors = 56, 
                        enrichment_rate_pct = 1.337, 
                        match_rate_pct = 1.337, 
                        matched_hems = 56, 
                        temporal_matches = 56, 
                        total_pageviews = 56, 
                        total_sessions = 56, 
                        unique_visitors = 56, 
                        vendor_matches = 56, )
                    ],
                date_range = neurograph.v1.models.pixel/date_range.pixel.DateRange(
                    end_date = '', 
                    start_date = '', ),
                enrichment_coverage = neurograph.v1.models.pixel/enrichment_coverage.pixel.EnrichmentCoverage(
                    email_valid_pct = 1.337, 
                    with_axon_id_pct = 1.337, 
                    with_company_pct = 1.337, 
                    with_email_pct = 1.337, 
                    with_industry_pct = 1.337, 
                    with_job_title_pct = 1.337, 
                    with_linkedin_pct = 1.337, 
                    with_name_pct = 1.337, 
                    with_phone_pct = 1.337, ),
                error = '',
                query_time_ms = 56,
                totals = neurograph.v1.models.pixel/client_pixel_totals.pixel.ClientPixelTotals(
                    avg_enrichment_rate_pct = 1.337, 
                    avg_match_rate_pct = 1.337, 
                    temporal_match_pct = 1.337, 
                    temporal_match_total = 56, 
                    total_enriched = 56, 
                    total_estimated_cost = 1.337, 
                    total_matched = 56, 
                    total_pageviews = 56, 
                    total_sessions = 56, 
                    total_visitors = 56, 
                    vendor_match_pct = 1.337, 
                    vendor_match_total = 56, )
            )
        else:
            return PixelClientPixelDetailsResponse(
        )
        """

    def testPixelClientPixelDetailsResponse(self):
        """Test PixelClientPixelDetailsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.dagster_info import DagsterInfo

class TestDagsterInfo(unittest.TestCase):
    """DagsterInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DagsterInfo:
        """Test DagsterInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DagsterInfo`
        """
        model = DagsterInfo()
        if include_optional:
            return DagsterInfo(
                id = 'dag_1234',
                job = 'initialize_personas_job',
                optional = 'some string, json, or whatever you want.',
                run = 'a8763df8-eec2-4856-8bf2-588cb49aa8b2',
                ts_created = 56
            )
        else:
            return DagsterInfo(
        )
        """

    def testDagsterInfo(self):
        """Test DagsterInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_model_job_detail_response import ReportingModelJobDetailResponse

class TestReportingModelJobDetailResponse(unittest.TestCase):
    """ReportingModelJobDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingModelJobDetailResponse:
        """Test ReportingModelJobDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingModelJobDetailResponse`
        """
        model = ReportingModelJobDetailResponse()
        if include_optional:
            return ReportingModelJobDetailResponse(
                cached = True,
                error = '',
                job = neurograph.v1.models.reporting/model_job_detail.reporting.ModelJobDetail(
                    active_build = 56, 
                    assignment_date = '', 
                    build_timestamp = '', 
                    client_id = '', 
                    job_id = '', 
                    model_type = '', 
                    model_version = '', ),
                predictions = [
                    neurograph.v1.models.reporting/model_prediction.reporting.ModelPrediction(
                        account_id = '', 
                        assignment_date = '', 
                        persona_id = '', 
                        persona_name = '', 
                        prediction_id = '', )
                    ],
                query_time_ms = 56,
                total_predictions = 56
            )
        else:
            return ReportingModelJobDetailResponse(
        )
        """

    def testReportingModelJobDetailResponse(self):
        """Test ReportingModelJobDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_buyer_scenario import ReportingBuyerScenario

class TestReportingBuyerScenario(unittest.TestCase):
    """ReportingBuyerScenario unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingBuyerScenario:
        """Test ReportingBuyerScenario
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingBuyerScenario`
        """
        model = ReportingBuyerScenario()
        if include_optional:
            return ReportingBuyerScenario(
                authored_boost = 1.337,
                blended_score = 1.337,
                cluster_boost = 1.337,
                cluster_ref_size = 56,
                cluster_size = 56,
                color = '',
                complexity = '',
                confidence = 1.337,
                description = '',
                diversity_factor = 1.337,
                final_score = 1.337,
                graph_paths = 56,
                graph_score = 1.337,
                graph_weight = 1.337,
                icon = '',
                intent = '',
                is_persona_authored = True,
                key_concepts = [
                    ''
                    ],
                market_concepts = [
                    neurograph.v1.models.reporting/scenario_market_concept.reporting.ScenarioMarketConcept(
                        concept_name = '', 
                        edge_type = '', 
                        link_source = '', 
                        similarity = 1.337, )
                    ],
                matched_products = 56,
                num_paths = 56,
                persona_context = '',
                primary_category = '',
                product_diversity = 1.337,
                product_paths = 56,
                product_score = 1.337,
                product_signal_count = 56,
                product_signal_gate = 1.337,
                purchase_likelihood = 1.337,
                relevance_pct = 1.337,
                scenario_name = '',
                scenario_resolved_id = '',
                scenario_type = '',
                scenario_variants = [
                    ''
                    ],
                shortest_path = 56,
                source_persona_id = '',
                tags = [
                    ''
                    ],
                timeline = '',
                top_paths = [
                    neurograph.v1.models.reporting/scenario_path.reporting.ScenarioPath(
                        edge_type = '', 
                        hops = 56, 
                        link_source = '', 
                        signal_source = '', 
                        similarity = 1.337, 
                        via_class = '', 
                        via_node = '', )
                    ],
                top_products = [
                    neurograph.v1.models.reporting/scenario_product.reporting.ScenarioProduct(
                        affinity_score = 1.337, 
                        affinity_tier = '', 
                        conversion_rate = 1.337, 
                        persona_purchase_pct = 1.337, 
                        product_name = '', 
                        product_type = '', 
                        purchase_pct_delta = 1.337, 
                        purchases = 56, )
                    ],
                trigger_event = ''
            )
        else:
            return ReportingBuyerScenario(
        )
        """

    def testReportingBuyerScenario(self):
        """Test ReportingBuyerScenario"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_theme_preset_list_response import OrganizationsThemePresetListResponse

class TestOrganizationsThemePresetListResponse(unittest.TestCase):
    """OrganizationsThemePresetListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsThemePresetListResponse:
        """Test OrganizationsThemePresetListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsThemePresetListResponse`
        """
        model = OrganizationsThemePresetListResponse()
        if include_optional:
            return OrganizationsThemePresetListResponse(
                error = '',
                presets = [
                    neurograph.v1.models.organizations/theme_preset_response.organizations.ThemePresetResponse(
                        category = '', 
                        color1 = '', 
                        color2 = '', 
                        color3 = '', 
                        color4 = '', 
                        color5 = '', 
                        created_at = '', 
                        description = '', 
                        error = '', 
                        id = 56, 
                        is_active = True, 
                        is_system = True, 
                        name = '', 
                        preview_url = '', 
                        primary_color = '', 
                        secondary_color = '', 
                        tags = [
                            ''
                            ], 
                        tertiary_color = '', 
                        updated_at = '', )
                    ],
                total = 56
            )
        else:
            return OrganizationsThemePresetListResponse(
        )
        """

    def testOrganizationsThemePresetListResponse(self):
        """Test OrganizationsThemePresetListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from neurograph.v1.models.reports_public_branding import ReportsPublicBranding
from typing import Optional, Set
from typing_extensions import Self

class ReportsPublicReportResponse(BaseModel):
    """
    ReportsPublicReportResponse
    """ # noqa: E501
    branding: Optional[ReportsPublicBranding] = Field(default=None, description="Organization branding")
    call_to_action: Optional[StrictStr] = None
    client_name: Optional[StrictStr] = Field(default=None, description="Client info")
    embed_url: Optional[StrictStr] = None
    error: Optional[StrictStr] = Field(default=None, description="Error message for non-200 responses")
    executive_summary: Optional[StrictStr] = Field(default=None, description="AI-generated summary")
    id: Optional[StrictStr] = Field(default=None, description="Report data")
    key_highlights: Optional[List[StrictStr]] = None
    key_stats: Optional[List[StrictInt]] = None
    linked_concepts: Optional[List[StrictStr]] = Field(default=None, description="Existing metadata")
    linked_themes: Optional[List[StrictStr]] = None
    main_insights: Optional[List[StrictStr]] = None
    name: Optional[StrictStr] = None
    og_image_url: Optional[StrictStr] = Field(default=None, description="OG Image URL for social sharing")
    report_type: Optional[StrictStr] = None
    report_type_label: Optional[StrictStr] = None
    thumbnail_url: Optional[StrictStr] = None
    ts_created: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["branding", "call_to_action", "client_name", "embed_url", "error", "executive_summary", "id", "key_highlights", "key_stats", "linked_concepts", "linked_themes", "main_insights", "name", "og_image_url", "report_type", "report_type_label", "thumbnail_url", "ts_created"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportsPublicReportResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of branding
        if self.branding:
            _dict['branding'] = self.branding.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportsPublicReportResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "branding": ReportsPublicBranding.from_dict(obj["branding"]) if obj.get("branding") is not None else None,
            "call_to_action": obj.get("call_to_action"),
            "client_name": obj.get("client_name"),
            "embed_url": obj.get("embed_url"),
            "error": obj.get("error"),
            "executive_summary": obj.get("executive_summary"),
            "id": obj.get("id"),
            "key_highlights": obj.get("key_highlights"),
            "key_stats": obj.get("key_stats"),
            "linked_concepts": obj.get("linked_concepts"),
            "linked_themes": obj.get("linked_themes"),
            "main_insights": obj.get("main_insights"),
            "name": obj.get("name"),
            "og_image_url": obj.get("og_image_url"),
            "report_type": obj.get("report_type"),
            "report_type_label": obj.get("report_type_label"),
            "thumbnail_url": obj.get("thumbnail_url"),
            "ts_created": obj.get("ts_created")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_preview_branding_response import OrganizationsPreviewBrandingResponse

class TestOrganizationsPreviewBrandingResponse(unittest.TestCase):
    """OrganizationsPreviewBrandingResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsPreviewBrandingResponse:
        """Test OrganizationsPreviewBrandingResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsPreviewBrandingResponse`
        """
        model = OrganizationsPreviewBrandingResponse()
        if include_optional:
            return OrganizationsPreviewBrandingResponse(
                accessibility_score = 56,
                error = '',
                tokens_dark = [
                    56
                    ],
                tokens_light = [
                    56
                    ],
                validation_warnings = {
                    'key' : [
                        ''
                        ]
                    }
            )
        else:
            return OrganizationsPreviewBrandingResponse(
        )
        """

    def testOrganizationsPreviewBrandingResponse(self):
        """Test OrganizationsPreviewBrandingResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_system_healthcheck_v2_snapshot import ClientSystemHealthcheckV2Snapshot

class TestClientSystemHealthcheckV2Snapshot(unittest.TestCase):
    """ClientSystemHealthcheckV2Snapshot unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientSystemHealthcheckV2Snapshot:
        """Test ClientSystemHealthcheckV2Snapshot
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientSystemHealthcheckV2Snapshot`
        """
        model = ClientSystemHealthcheckV2Snapshot()
        if include_optional:
            return ClientSystemHealthcheckV2Snapshot(
                client_id = '',
                client_name = '',
                client_uid = '',
                error_json = [
                    56
                    ],
                error_message = '',
                graph_json = [
                    56
                    ],
                graph_version = 56,
                id = '',
                integration_mode = '',
                metrics_json = [
                    56
                    ],
                org_id = '',
                org_name = '',
                org_uid = '',
                result_success = True,
                run_date = '',
                status = '',
                summary_json = [
                    56
                    ],
                ts_finished = '',
                ts_started = ''
            )
        else:
            return ClientSystemHealthcheckV2Snapshot(
        )
        """

    def testClientSystemHealthcheckV2Snapshot(self):
        """Test ClientSystemHealthcheckV2Snapshot"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
